@@ -8,19 +8,17 @@
 <meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript">
 //<!--
-jQuery(function () {
-    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
-    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
-    jQuery("form.comment").submit(function () {
-        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
-        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
-        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
-        jQuery("//input[@type='submit']").attr({ "disabled": true });
-        return true;
-    });
-});
+var app = Img0ch.App;
+app.setBBSURI("<?cs var:BBSURI ?>");
+app.setCGIURI("<?cs var:CGIURI ?>");
+app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
+function redir(element) {
+    app.redirectRenderer(element);
+    return true;
+}
 //-->
 </script>
 <style type="text/css">
@@ -80,9 +78,9 @@ jQuery(function () {
  <tr>
   <td>
    <small>
-   <?cs each:item = Threads ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>:</a> <?cs var:item.subject ?> <a href="#<?cs var:item.index ?>">(<?cs var:item.res ?>)</a>
+   <?cs each:item = Threads ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.index ?>:</a> <?cs var:item.subject ?> <a href="#<?cs var:item.index ?>">(<?cs var:item.res ?>)</a>
    <?cs /each ?>
-   <?cs each:item = Stored ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>: <?cs var:item.subject ?> (<?cs var:item.res ?>)</a>
+   <?cs each:item = Stored ?><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.index ?>: <?cs var:item.subject ?> (<?cs var:item.res ?>)</a>
    <?cs /each ?>
    <div align="right"><b><a href="<?cs var:BBSURI ?>/subback.html">Xbhꗗ͂</a></b></div>
    </small>
@@ -112,10 +110,11 @@ jQuery(function () {
  OF<input type="text" name="FROM" size="19"> E-mailF<input type="text" name="mail" size="19"><br><ul>
 <!--t@CI\(BBS_MODEpicturȅꍇ)-->
    <?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="74"><br><?cs /if ?>
-<textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
-<b><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/">Sǂ</a>
-<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/l50">ŐV50</a>
-<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/1-100">1-100</a>
+ <textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
+ <?cs if:BBS_IMG_REQUIRE_REMOVE_KEY ?>폜pXF<input type="password" name="pass"><br><?cs /if ?>
+<b><a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/" onclick="redir(this)">Sǂ</a>
+<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/l50" onclick="redir(this)">ŐV50</a>
+<a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/1-100" onclick="redir(this)">1-100</a>
 <a href="#top">̃gbv</a> <a href="./index.html">[h</a>
    </ul>
    </form>
