@@ -6,23 +6,14 @@
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 <meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
-<!--meta.txto͕-->
-<?cs if:META ?>
-<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script><script type="text/javascript" src="<?cs var:StaticURI ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript">
 //<!--
-jQuery(function () {
-    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
-    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
-    jQuery("form.comment").submit(function () {
-        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
-        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
-        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
-        jQuery("//input[@type='submit']").attr({ "disabled": true });
-        return true;
-    });
-});
+var app = Img0ch.App;
+app.setBBSURI("<?cs var:BBSURI ?>");
+app.setCGIURI("<?cs var:CGIURI ?>");
+app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
 //-->
 </script>
 <style type="text/css">
