@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: MailPost.pm 121 2007-01-23 13:47:52Z hikarin $
+# $Id: MailPost.pm 181 2007-02-05 14:02:27Z hikarin $
 #
 
 package Img0ch::App::MailPost;
@@ -263,7 +263,7 @@ sub _get_host {
         if ( $from !~ /docomo\.ne\.jp/xms
             and $from !~ /ezweb\.ne\.jp/xms
             and $from !~ /jp-[dhtckrnsq]\.ne\.jp/xms
-            and $from !~ /vodafone\.ne\.jp/xms
+            and $from !~ /[dhtckrnsq]\.vodafone\.ne\.jp/xms
             and $from !~ /softbank\.ne\.jp/xms ) {
             $iApp->set_error('MAILPOST_FROM_NOT_MOBILE_ADDRESS');
             return 0;
@@ -296,7 +296,7 @@ use base qw(Img0ch::RequestIF);
 
 BEGIN {
     my $pkg = __PACKAGE__;
-    for my $method (qw(agent bbs fh ip ip_int key msec now)) {
+    for my $method (qw(agent fh ip ip_int msec now)) {
         no strict 'refs';
         *{"${pkg}::${method}"} = sub { $_[0]->{__orig}->$method };
     }
