@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Plugin.pm 99 2007-01-16 13:52:38Z hikarin $
+# $Id: Plugin.pm 164 2007-02-02 14:52:06Z hikarin $
 #
 
 package Img0ch::Plugin;
@@ -28,7 +28,7 @@ sub new {
     my $repos_entries = $iKernel->get_repos_path('plugin_entries');
 
     bless {
-        _bbs           => $iBBS->id(),
+        _bbs           => $iBBS->get_id(),
         __constructors => {},
         __error        => undef,
         _data          => $iKernel->get_repos($repos_data),
@@ -53,11 +53,11 @@ sub new {
 }
 
 sub load {
-    my ( $iPlugin, $from, $iBBS, $key ) = @_;
+    my ( $iPlugin, $from, $called, $iBBS, $key ) = @_;
     my $bbs;
 
     if ($iBBS) {
-        $bbs = $iBBS->id();
+        $bbs = $iBBS->get_id();
     }
     else {
         $iBBS = $iPlugin->{__i0_bbs};
@@ -112,7 +112,7 @@ sub load {
                 [ $method_ref, $instance, $id, "${class}.${meth}" ];
         }
         elsif ( $constructor and !$instance_cache->{$class} ) {
-            my $instance = $constructor->( $class, $iBBS, $key );
+            my $instance = $constructor->( $class, $iBBS, $key, $called );
             $constructors->{$class}   = $constructor;
             $instance_cache->{$class} = $instance;
             push @{$stack},
@@ -128,7 +128,8 @@ sub load {
 sub do {
     my ( $iPlugin, $from, $dto, $args ) = @_;
     $args ||= [];
-    for my $plugin ( sort { $a->[3] cmp $b->[3] } @{ $iPlugin->load($from) } )
+    for my $plugin (
+        sort { $a->[3] cmp $b->[3] } @{ $iPlugin->load( $from, 'do' ) } )
     {
         $plugin->[0]->( ( $plugin->[1] || $dto ), $plugin->[2], @{$args} )
             or return 0;
@@ -138,7 +139,7 @@ sub do {
 
 sub iterator {
     my ( $iPlugin, $from, $fallback ) = @_;
-    my $plugin = $iPlugin->load($from);
+    my $plugin = $iPlugin->load( $from, 'iterator' );
     if ( @{$plugin} ) {
         @{$plugin} = sort { $a->[3] cmp $b->[3] } @{$plugin};
         return sub { $_->[0]->( $_->[1], @_ ) for @{$plugin} }
