@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 117 2007-01-21 14:55:55Z hikarin $
+# $Id: Install.pm 181 2007-02-05 14:02:27Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -58,6 +58,11 @@ sub install {
             },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Filter::Akismet',
+            methods => { check => 'bbs.filter', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Filter::BanASCII',
             methods => { is_ascii_only => 'bbs.filter', },
@@ -78,6 +83,11 @@ sub install {
             },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Filter::Host',
+            methods => { check => 'bbs.filter', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Filter::IP',
             methods => { check => 'bbs.filter', },
@@ -172,7 +182,7 @@ sub install {
         {   package => 'Img0ch::Plugin::Upload::Expires',
             methods => {
                 at_post_upload => 'bbs.upload.post',
-                at_post_write => 'bbs.wrie.post',
+                at_post_write => 'bbs.write.post',
             },
         }
     );
@@ -180,6 +190,8 @@ sub install {
 #        {   package => 'Img0ch::Plugin::Upload::Note',
 #            methods => {
 #                save => 'bbs.upload.post',
+#                from_bbs => 'bbs.rewrite',
+#                from_read => 'read.rewrite',
 #            },
 #        }
 #    );
