@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Thread.pm 99 2007-01-16 13:52:38Z hikarin $
+# $Id: Thread.pm 164 2007-02-02 14:52:06Z hikarin $
 #
 
 package Img0ch::Thread;
@@ -26,7 +26,7 @@ sub new {
     my $iKernel = $iBBS->get_kernel();
 
     bless {
-        _bbs          => $iBBS->id(),
+        _bbs          => $iBBS->get_id(),
         _count        => 0,
         _kernel       => $iKernel,
         _key          => ( $key || 0 ),
