@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Setting.pm 123 2007-01-23 13:52:09Z hikarin $
+# $Id: Setting.pm 164 2007-02-02 14:52:06Z hikarin $
 #
 
 package Zeromin::Setting;
@@ -222,7 +222,7 @@ sub save {
     my $iBBS = $zSetting->{__bbs};
     if ( !$no_disk ) {
         my $iKernel = $zSetting->{__kernel};
-        my $dir     = $iBBS->bbs();
+        my $dir     = $iBBS->get_name();
         $path ||= $zSetting->path();
         local ( $!, *FH );
         open *FH, ">${path}"    ## no critic
